"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.diagnosticSettingDefault = exports.formattingDefaults = exports.modeConfigurationDefault = exports.MonacoGraphQLAPI = void 0;
var monaco_editor_1 = require("monaco-editor");
var MonacoGraphQLAPI = (function () {
    function MonacoGraphQLAPI(_a) {
        var languageId = _a.languageId, schemas = _a.schemas, modeConfiguration = _a.modeConfiguration, formattingOptions = _a.formattingOptions, diagnosticSettings = _a.diagnosticSettings;
        this._onDidChange = new monaco_editor_1.Emitter();
        this._schemas = null;
        this._schemasById = Object.create(null);
        this._externalFragmentDefinitions = null;
        this._languageId = languageId;
        if (schemas) {
            this.setSchemaConfig(schemas);
        }
        this.setModeConfiguration(modeConfiguration);
        this.setFormattingOptions(formattingOptions);
        this.setDiagnosticSettings(diagnosticSettings);
    }
    Object.defineProperty(MonacoGraphQLAPI.prototype, "onDidChange", {
        get: function () {
            return this._onDidChange.event;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MonacoGraphQLAPI.prototype, "languageId", {
        get: function () {
            return this._languageId;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MonacoGraphQLAPI.prototype, "modeConfiguration", {
        get: function () {
            return this._modeConfiguration;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MonacoGraphQLAPI.prototype, "schemas", {
        get: function () {
            return this._schemas;
        },
        enumerable: false,
        configurable: true
    });
    MonacoGraphQLAPI.prototype.schemasById = function () {
        return this._schemasById;
    };
    Object.defineProperty(MonacoGraphQLAPI.prototype, "formattingOptions", {
        get: function () {
            return this._formattingOptions;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MonacoGraphQLAPI.prototype, "diagnosticSettings", {
        get: function () {
            return this._diagnosticSettings;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MonacoGraphQLAPI.prototype, "externalFragmentDefinitions", {
        get: function () {
            return this._externalFragmentDefinitions;
        },
        enumerable: false,
        configurable: true
    });
    MonacoGraphQLAPI.prototype.setSchemaConfig = function (schemas) {
        this._schemas = schemas || null;
        this._schemasById = schemas.reduce(function (result, schema) {
            result[schema.uri] = schema;
            return result;
        }, Object.create(null));
        this._onDidChange.fire(this);
    };
    MonacoGraphQLAPI.prototype.setExternalFragmentDefinitions = function (externalFragmentDefinitions) {
        this._externalFragmentDefinitions = externalFragmentDefinitions;
    };
    MonacoGraphQLAPI.prototype.setModeConfiguration = function (modeConfiguration) {
        this._modeConfiguration = modeConfiguration || Object.create(null);
        this._onDidChange.fire(this);
    };
    MonacoGraphQLAPI.prototype.setFormattingOptions = function (formattingOptions) {
        this._formattingOptions = formattingOptions || Object.create(null);
        this._onDidChange.fire(this);
    };
    MonacoGraphQLAPI.prototype.setDiagnosticSettings = function (diagnosticSettings) {
        this._diagnosticSettings = diagnosticSettings || Object.create(null);
        this._onDidChange.fire(this);
    };
    return MonacoGraphQLAPI;
}());
exports.MonacoGraphQLAPI = MonacoGraphQLAPI;
exports.modeConfigurationDefault = {
    documentFormattingEdits: true,
    documentRangeFormattingEdits: false,
    completionItems: true,
    hovers: true,
    documentSymbols: false,
    tokens: false,
    colors: false,
    foldingRanges: false,
    diagnostics: true,
    selectionRanges: false,
};
exports.formattingDefaults = {
    prettierConfig: {
        tabWidth: 2,
    },
};
exports.diagnosticSettingDefault = {
    jsonDiagnosticSettings: {
        schemaValidation: 'error',
    },
};
//# sourceMappingURL=api.js.map