import { MonacoGraphQLAPI, formattingDefaults, modeConfigurationDefault, diagnosticSettingDefault, } from './api';
export { MonacoGraphQLAPI, modeConfigurationDefault };
import * as monaco from 'monaco-editor';
export * from './typings';
export const LANGUAGE_ID = 'graphql';
export function initializeMode({ schemas, formattingOptions, modeConfiguration, diagnosticSettings, }) {
    const api = new MonacoGraphQLAPI({
        languageId: LANGUAGE_ID,
        schemas,
        formattingOptions: {
            ...formattingDefaults,
            ...formattingOptions,
            prettierConfig: {
                ...formattingDefaults.prettierConfig,
                ...formattingOptions?.prettierConfig,
            },
        },
        modeConfiguration: {
            ...modeConfigurationDefault,
            ...modeConfiguration,
        },
        diagnosticSettings: {
            ...diagnosticSettingDefault,
            ...diagnosticSettings,
        },
    });
    monaco.languages.onLanguage(LANGUAGE_ID, () => {
        getMode().then(mode => mode.setupMode(api));
    });
    return api;
}
function getMode() {
    return import('./graphqlMode');
}
//# sourceMappingURL=monaco.contribution.js.map